summaryrefslogtreecommitdiffstats
path: root/templates/annotated/basicapp.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:09:42 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:09:42 -0600
commit2df6bde18ab40472f2df8637cf6456cb80dc2329 (patch)
tree5a4362124ff46786fce835d2f1e7d583c92a5670 /templates/annotated/basicapp.py
parentbe6cfa4b990910e65e8d2f4f212eba3f7da6ee72 (diff)
downloadpytde-2df6bde18ab40472f2df8637cf6456cb80dc2329.tar.gz
pytde-2df6bde18ab40472f2df8637cf6456cb80dc2329.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'templates/annotated/basicapp.py')
-rw-r--r--templates/annotated/basicapp.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/templates/annotated/basicapp.py b/templates/annotated/basicapp.py
index a725004..50940ea 100644
--- a/templates/annotated/basicapp.py
+++ b/templates/annotated/basicapp.py
@@ -36,23 +36,23 @@ copyright holder.
import sys
from tdecore import TDEApplication, TDECmdLineArgs, TDEAboutData
-from tdeui import KMainWindow
+from tdeui import TDEMainWindow
"""
Most PyKDE applications will need a main window - the is the top
-level widget (the parent for all other widgets). KMainWindow has
+level widget (the parent for all other widgets). TDEMainWindow has
more functionality than shown here (see more complex templates).
It has the ability to create the other major parts of the user
interface - the main view, menus, toolbars, etc.
-Usually you provide a subclass of KMainWindow, construct menus
+Usually you provide a subclass of TDEMainWindow, construct menus
and toolbars in the subclass' __init__ method, and provide
slots for menu/toolbar actions in separate methods.
"""
-class MainWin (KMainWindow):
+class MainWin (TDEMainWindow):
def __init__ (self, *args):
- apply (KMainWindow.__init__, (self,) + args)
+ apply (TDEMainWindow.__init__, (self,) + args)
#-------------------- main ------------------------------------------------
@@ -101,7 +101,7 @@ TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
# until there is a TDEApplication instance
app = TDEApplication ()
# instantiate the subclass of KMainWindow
mainWindow = MainWin (None, "main window")
# create the display
@@ -101,7 +101,7 @@ TDECmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
# until there is a TDEApplication instance
app = TDEApplication ()
-# instantiate the subclass of KMainWindow
+# instantiate the subclass of TDEMainWindow
mainWindow = MainWin (None, "main window")
# create the display